@@ -13,5 +13,14 @@ class Camera:
             x, y = position
             cursor_orientations = [orientation+theta for theta in self.thetas]
             self.cursor_positions = [(x-int(self.cams_range*numpy.sin(numpy.pi*(angle)/180)), y-int(self.cams_range*numpy.cos(numpy.pi*(angle)/180))) for angle in cursor_orientations]
-            value = [vue.map_img_rgb.getpixel(cursor_position)[2] for cursor_position in self.cursor_positions]
-            return value
\ No newline at end of file
+            # values = [vue.map_img_rgb.getpixel(cursor_position)[2] for cursor_position in self.cursor_positions]
+            values = []
+            for cursor_position in self.cursor_positions :
+                try :
+                    value = vue.map_img_rgb.getpixel(cursor_position)[2]
+                except IndexError :
+                    value = 240
+                except :
+                    raise
+                valurs.append(value)
+            return values
\ No newline at end of file
